@@ -11,7 +11,7 @@ The changes are:
   If `intersphinx <https://www.sphinx-doc.org/en/master/usage/extensions/intersphinx.html>`_
   is used this will now be a link to the Python documentation.
 
-  Since :github:pull:`154 <agronholm/sphinx-autodoc-typehints>` this feature is now available upstream.
+  Since :github:pull:`154 <tox-dev/sphinx-autodoc-typehints>` this feature is now available upstream.
 
 * If the signature of the object cannot be read, the signature provided by Sphinx will be used
   rather than raising an error.
@@ -153,6 +153,7 @@ from sphinx.application import Sphinx
 from sphinx.errors import ExtensionError
 from sphinx.util.inspect import signature as Signature
 from sphinx.util.inspect import stringify_signature
+from typing_extensions import Self
 
 # this package
 from sphinx_toolbox.utils import (
@@ -323,6 +324,8 @@ def format_annotation(annotation: Any, fully_qualified: bool = False) -> str:
 		return f":py:obj:`{annotation}`"
 	elif annotation is Ellipsis:
 		return "..."
+	elif annotation is Self:
+		return f":py:obj:`{prefix}typing.Self`"
 	elif annotation is itertools.cycle:
 		return f":func:`{prefix}itertools.cycle`"
 	elif annotation is types.GetSetDescriptorType:  # noqa: E721
@@ -918,5 +921,7 @@ def _resolve_forwardref(
 	module_dict = sys.modules[module].__dict__
 	if sys.version_info < (3, 9):
 		return fr._evaluate(module_dict, module_dict)
+	elif sys.version_info >= (3, 12):
+		return fr._evaluate(module_dict, module_dict, set(), recursive_guard=set())
 	else:
 		return fr._evaluate(module_dict, module_dict, set())
